##########################################################################
#                                                                        #
#              Copyright (C) 1997, Cobalt Microserver, Inc               #
#                          All rights reserved                           #
#                                                                        #
# Filename: mkdiscuss                                                    #
#                                                                        #
# Author(s): Timothy Stonis                                              #
#                                                                        #
# Description: Setup the discussion forum for a newly created group      #
#                                                                        #
##########################################################################

SOURCE_DIR=/etc/skel/discuss
DISCUSS_HTML_DIR=/home/httpd/html/cobalt/discuss
DISCUSS_CGI_DIR=/home/httpd/cgi-bin/cobalt/discuss
IPADDR=`ifconfig eth0 | grep "inet" | cut -f 2 -d":" | cut -f 1 -d" "`

if [ X$1 != X ]; then
  GROUP=$1
  CGROUP=`toupper $GROUP`
else
  echo "No group specified, exiting."
  exit 1
fi

# Make the group html and cgi directories

if [ -d $DISCUSS_HTML_DIR/$GROUP ]; then
 echo "Error: $DISCUSS_HTML_DIR/$GROUP already exists." 
 #exit 1
else
 mkdir $DISCUSS_HTML_DIR/$GROUP
 mkdir $DISCUSS_HTML_DIR/$GROUP/private
 touch $DISCUSS_HTML_DIR/$GROUP/data.txt
fi

if [ -d $DISCUSS_CGI_DIR/$GROUP ]; then
 echo "Error: $DISCUSS_CGI_DIR/$GROUP already exists."
 #exit 1
else
 mkdir $DISCUSS_CGI_DIR/$GROUP
fi

# Copy the Index file from the skel directory to the target, filling in 
# the group name...
cat $SOURCE_DIR/index.html | sed -e "s/XXX/$CGROUP/g" \
  -e "s/GROUP/$GROUP/g" > \
    $DISCUSS_HTML_DIR/$GROUP/index.html

# Copy the redirect file from the skel directory to the target, filling in
# the group name...
cat $SOURCE_DIR/redirect.html | sed -e "s/XXX/$CGROUP/g" \
  -e "s/GROUP/$GROUP/g" > \
    $DISCUSS_HTML_DIR/$GROUP/redirect.html

# Copy the index.cgi file from the skel directory to the target, filling in
# the group name...
cat $SOURCE_DIR/index.cgi | sed -e "s/CROUP/$CGROUP/g" \
  -e "s/GROUP/$GROUP/g" > $DISCUSS_CGI_DIR/$GROUP/index.cgi
chmod +x $DISCUSS_CGI_DIR/$GROUP/index.cgi



# Copy the post file from the skel directory to the target, filling in 
# the group name...
cat $SOURCE_DIR/post.sh | sed -e "s/HOSTIP/$IPADDR/g" \
  -e "s/GROUP/$GROUP/g" > $DISCUSS_CGI_DIR/$GROUP/post.sh
chmod +x $DISCUSS_CGI_DIR/$GROUP/post.sh
 
# Copy the cgi perl script from the skel directory to the target, filling in
# the group name...
cat $SOURCE_DIR/wwwboard.pl | sed -e "s/HOSTIP/$IPADDR/g" \
  -e "s/GROUP/$GROUP/g" -e "s/CROUP/$CGROUP/g" \
  > $DISCUSS_CGI_DIR/$GROUP/wwwboard.pl
chmod +x $DISCUSS_CGI_DIR/$GROUP/wwwboard.pl

cat $SOURCE_DIR/wwwadmin.pl | sed -e "s/HOSTIP/$IPADDR/g" \
  -e "s/GROUP/$GROUP/g" -e "s/CROUP/$CGROUP/g" \
  > $DISCUSS_CGI_DIR/$GROUP/wwwadmin.pl
chmod +x $DISCUSS_CGI_DIR/$GROUP/wwwadmin.pl

cat $SOURCE_DIR/followup.sh | sed -e "s/GROUP/$GROUP/g" \
   > $DISCUSS_CGI_DIR/$GROUP/followup.sh
chmod +x $DISCUSS_CGI_DIR/$GROUP/followup.sh

# Add the access restrictions...
cp /home/httpd/html/groups/$GROUP/private/.htaccess \
  $DISCUSS_HTML_DIR/$GROUP/.htaccess  
cp /home/httpd/html/groups/$GROUP/private/.htaccess \
  $DISCUSS_CGI_DIR/$GROUP/.htaccess

# Change the permissions on all the files so the port 80 server can make
# changes.
chgrp -R httpd $DISCUSS_HTML_DIR/$GROUP
chmod -R g+w $DISCUSS_HTML_DIR/$GROUP
